OC.L10N.register(
    "text",
    {
    "New text file" : "Ficheru nuevu de testu",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu perpasa la direutiva de xuba upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "No file was uploaded" : "Nun se xubieron fichjeros",
    "Missing a temporary folder" : "Falta un direutoriu temporal",
    "Could not write file to disk" : "Nun pudo escribise nel discu'l ficheru",
    "A PHP extension stopped the file upload" : "Una estensión de PHP paró la xuba de ficheros",
    "Text" : "Testu",
    "Guest" : "Convidáu/ada",
    "guest" : "invitáu",
    "Saving …" : "Guardando...",
    "Saved" : "Guardáu",
    "Keyboard shortcuts" : "Atayos de tecláu",
    "Translate" : "Traducir",
    "Replace" : "Trocar",
    "Unsupported image type" : "Triba non sofitada d'imaxe",
    "Undo" : "Desfacer",
    "Info" : "Info",
    "Warning" : "Alvertencia",
    "Edit" : "Editar"
},
"nplurals=2; plural=(n != 1);");
